@@ -69,7 +69,18 @@ as_gt <- function(x, include = everything(), return_calls = FALSE, exclude = NUL
   if (!is.null(x$list_output$source_note)) {
     gt_calls[["tab_source_note"]] <- expr(gt::tab_source_note(source_note = !!x$list_output$source_note))
   }
-  if (return_calls == TRUE) return(gt_calls)
+
+  # adding user-specified calls ------------------------------------------------
+  insert_expr_after <- get_theme_element("as_gt-lst:addl_cmds")
+  gt_calls <-
+    purrr::reduce(
+      .x = seq_along(insert_expr_after),
+      .f = function(x, y) add_expr_after(calls = x,
+                                         add_after = names(insert_expr_after[y]),
+                                         expr = insert_expr_after[[y]],
+                                         new_name = paste0("user_added", y)),
+      .init = gt_calls
+    )
 
   # converting to charcter vector ----------------------------------------------
   include <- var_input_to_string(data = vctr_2_tibble(names(gt_calls)),
@@ -84,6 +95,9 @@ as_gt <- function(x, include = everything(), return_calls = FALSE, exclude = NUL
   include <- include %>% setdiff(exclude)
   include <- "gt" %>% union(include)
 
+  # return calls, if requested -------------------------------------------------
+  if (return_calls == TRUE) return(gt_calls[include])
+
   # taking each gt function call, concatenating them with %>% separating them
   gt_calls[include] %>%
     # adding default gt formatting options
