@@ -3,7 +3,7 @@
 #' @name print_gtsummary
 #' @param x An object created using gtsummary functions
 #' @param print_engine String indicating the print method. Must be one of
-#' `"gt"`, `"kable"`, `"kable_extra"`, `"flextable"`, `"huxtable"`, `"tibble"`
+#' `"gt"`, `"kable"`, `"kable_extra"`, `"flextable"`, `"tibble"`
 #' @param ... Not used
 #' @author Daniel D. Sjoberg
 #' @seealso [tbl_summary] [tbl_regression] [tbl_uvregression] [tbl_merge] [tbl_stack]
@@ -21,7 +21,7 @@ print.gtsummary <- function(x, print_engine = NULL, ...) {
 
   # checking engine
   accepted_print_engines <-
-    c("gt", "kable", "kable_extra", "flextable", "huxtable", "tibble")
+    c("gt", "kable", "kable_extra", "flextable", "tibble")
   if (!rlang::is_string(print_engine) || !print_engine %in% accepted_print_engines) {
     stop(glue(
       "Select a valid print engine. ",
@@ -36,7 +36,7 @@ print.gtsummary <- function(x, print_engine = NULL, ...) {
     "kable" = as_kable(x),
     "flextable" = as_flextable(x),
     "kable_extra" = as_kable_extra(x),
-    "huxtable" = as_huxtable(x),
+    # "huxtable" = as_huxtable(x),
     "tibble" = as_tibble(x)
   ) %>%
     print()
@@ -101,7 +101,7 @@ knit_print.gtsummary <- function(x, ...) {
     "kable" = as_kable(x),
     "flextable" = as_flextable(x),
     "kable_extra" = as_kable_extra(x),
-    "huxtable" = as_huxtable(x),
+    # "huxtable" = as_huxtable(x),
     "tibble" = as_tibble(x)
   ) %>%
       knitr::knit_print()
