@@ -4,9 +4,7 @@ knitr::opts_chunk$set(
   eval = FALSE,
   comment = "#>"
 )
-
-## ----exit_early, include = FALSE, eval = !requireNamespace("gt")--------------
-#  knitr::knit_exit()
+library(gtsummary)
 
 ## -----------------------------------------------------------------------------
 #  options(gtsummary.pvalue_fun = function(x) style_pvalue(x, digits = 2))
@@ -20,10 +18,6 @@ knitr::opts_chunk$set(
 ## -----------------------------------------------------------------------------
 #  options(gtsummary.print_engine = "gt")
 
-## ---- eval = TRUE-------------------------------------------------------------
-library(gtsummary)
-tbl_summary(trial)$gt_calls %>% head(n = 4)
-
 ## -----------------------------------------------------------------------------
 #  options(gtsummary.as_gt.addl_cmds = "gt::tab_options(table.font.size = 'small', data_row.padding = gt::px(1))")
 
