@@ -109,6 +109,14 @@ test_that("add_p with custom p-value function", {
   )
 })
 
+test_that("Wilcoxon and Kruskal-Wallis p-values match ", {
+  t1 <- trial[c("trt", "age", "marker")] %>% tbl_summary(by = trt) %>% add_p(test = all_continuous() ~ wilcox.test)
+  t2 <- trial[c("trt", "age", "marker")] %>% tbl_summary(by = trt) %>% add_p(test = all_continuous() ~ kruskal.test)
+  expect_true(
+    all(t1$meta_data$p.value - t2$meta_data$p.value < 0.001)
+  )
+})
+
 
 # test-add_p.tbl_cross----------------------------------------------------------
 context("test-add_p.tbl_cross")
